"""
Skill manifest models.

This module provides the complete schema for Skill Manifest v1.0,
a standardized declarative format for describing AI coding assistant skill packs.
"""

from aphub_sdk.schemas.skill_manifest.base import SkillManifestV1
from aphub_sdk.schemas.skill_manifest.spec import (
    CommandEntry,
    SkillEntry,
    SkillSpec,
)

__all__ = [
    "SkillManifestV1",
    "SkillSpec",
    "SkillEntry",
    "CommandEntry",
]
