"""
aphub Python SDK
"""

__version__ = "0.1.0"

from aphub_sdk.client import HubClient, HubClientError

# Re-export commonly used schemas
from aphub_sdk.schemas import (
    AgentManifestV1,
    Agent,
    AgentVersion,
    AgentSummary,
    PushResponse,
    PullResponse,
    SearchResponse,
    HubError,
    ErrorCode,
    SkillManifestV1,
    Skill,
    SkillVersion,
    SkillSummary,
    SkillPushResponse,
    SkillPullResponse,
    SkillSearchResponse,
)

# Export SDK-specific response models
from aphub_sdk.client import AuthResponse, RateResponse

__all__ = [
    "HubClient",
    "HubClientError",
    "__version__",
    # Agent Schemas
    "AgentManifestV1",
    "Agent",
    "AgentVersion",
    "AgentSummary",
    "PushResponse",
    "PullResponse",
    "SearchResponse",
    # Skill Schemas
    "SkillManifestV1",
    "Skill",
    "SkillVersion",
    "SkillSummary",
    "SkillPushResponse",
    "SkillPullResponse",
    "SkillSearchResponse",
    # Errors
    "HubError",
    "ErrorCode",
    # SDK-specific responses
    "AuthResponse",
    "RateResponse",
]
